==> worlds_tloz_ph-0.3.1.tar.gz: worlds_tloz_ph-0.3.1/src/worlds/tloz_ph/docs/tricks_and_skips.md <==
# List of tricks, skips and glitches by area, marked with logic requirements and with video links when available
Thanks to the [glitches spreadsheet](https://docs.google.com/spreadsheets/d/18NCGJjt9wil1gnRB2rZO9DIv_5etKmRf0sAH66i5SVQ/edit?usp=sharing) for collecting everything relevant to the vanilla game!

## Mercay island
- [Swordless/bombless Mountain Passage](https://www.youtube.com/watch?v=6_J14xLnVWM). Savewarping from the back entrance of Mountain Passage also works (Glitched Logic)
- [Mercay out of bounds](https://www.youtube.com/watch?v=IcyfYE68LUQ). (Glitched Logic)

## TotOK
### Time Logic
Phantom hourglass time logic is now available! On easy, it calculates the time it takes to walk (no rolling) from one 
floor to the next with various items. It then calculates the time to get each location from the start of their floor, 
for various items. It does not account for golden time pots. Medium halves the logically required time, and hard 
quarters it, while beginner doubles it. The longest probable required amount of time is around 10 minutes for beginner, 
5 for easy, 2.5 for medium and 1.25 for hard. It will generate slightly more sand than necessary based on your settings.
There's also a setting for how to count hearts as time, for only requiring the phantom hourglass item or for not 
calculating logic at all! Good luck!

### Tricks and Skips
- Kill b1 phantoms with
  - Phantom Sword (all settings)
  - Bow or (Sword + 2 Spirits of Power) or Hammer (Kill phantoms with stun). Push them into the pit by the grapple pegs
  - Grappling Hook (Kill phantoms with weapon)
 - B2 hit swtiches with pots from floor above (Hard Logic)
 - B2 hit switch over fire with pot (Hard Logic)
 - B2 Have phantom pick up key
   - Throw pot at phantom to pick it up (Normal logic)
   - Lure phantom to start of room (Hard Logic)
 - B2 [boomerang return key](https://www.youtube.com/watch?v=ftt3lP_qQDc) (doesn't effect logic)
 - B2 hammer clip bombchu switch (Glitched logic)
 - B3 Kill all phantoms (kill phantoms with traps)
 - B4 throw pot from floor above to hit switch behind SE gust of wind (Hard logic)
 - B4 [Boomerang return key](https://youtu.be/FbvG2Jzs68g?t=14) (Glitched logic)
 - B4 hit switches with hammer clips (Glitched Logic)
 - B5 Chest backwards with BCL and boomerang (Doesn't effect logic, but saves a key!)
 - B7 push phantoms into pits (kill phantoms with stun/weapon)
 - B8 push phantoms into pits (kill phantoms with stun/weapon)
 - B8 Hammer clip bombchu switch (Glitched Logic)
 - B10 Hammer switches (doesn't effect logic)

## Cannon island
 - [Bomb garden skip](https://www.youtube.com/watch?v=KtJ2GkNlr3E) (doesn't effect logic)

## Isle of Ember
- [Grapple chest without grapple](https://www.youtube.com/watch?v=IZiyFStyRfg) (Glitched Logic)

## Temple of Fire
- Hit 1F spin switch with things other than sword: bombs, chus and boomerang (Hard Logic)
- [Rat key early](https://www.youtube.com/watch?v=OJ-CwmYvWrc) (really tricky to kill rat with just boomerang, doesn't effect logic if killed with hammer clip)

## Temple of Courage
- 1F Hammer clip all the switches (Glitched Logic)
- B1 Invisible maze early
  - With grapple (all settings)
  - [With boomerang](https://www.youtube.com/watch?v=2DAUMNNQNhw) (Glitched Logic)
- B1 Boomerang Skip with Spirit of Courage (Not Implemented)

## Nyave's Ship
- Kill miblins with barrels (Hard Logic)

## Temple of Wind
- [Boss key early](https://www.youtube.com/watch?v=16hl9_mOLds) (not implemented)
- [B1 out of bounds](https://www.youtube.com/watch?v=ertGqXyGL-c) (doesn't effect logic)

## Ghost Ship
- B3 hammer clip switch (doesn't effect logic)

## Goron Island
- [Goron Temple early](https://www.youtube.com/watch?v=tUjm0CZAEVU) (Hard Logic)

## Goron Temple
- Hammer clips (Glitched logic)
- B2 early shortcut [rock roll](https://www.youtube.com/watch?v=FrdBA7idCWI) [BCL](https://www.youtube.com/watch?v=BUWBODrGF-0) (Doesn't effect logic)
- [Boss key early](https://www.youtube.com/watch?v=BUWBODrGF-0) (Doesn't effect logic)
- [Boss key skip](https://www.youtube.com/watch?v=Z4cupNcYcUg) (Not Implemented)

## Dee Ess Island
- Kill Eye brutes with their own bombs (Hard Logic)

## Temple of Ice
- 1F [Color Switch early](https://www.youtube.com/watch?v=na6olZJgE3M) (Hard Logic)
- 3F Hit entrance switch with bomb held over head (All Settings)
- 3F hit boomerang switches with bow (Hard Logic)
- 1F shortcut hammer clip (Glitched Logic)
- B1 Hammer clip color switch (Glitched logic)
- B1 [BCL switch skip](https://www.youtube.com/watch?v=aED-Yp_5MXo) (Glitched Logic)
- B1 Jump to boomerang switches and hit with bow (Hard Logic)
- B2 Hammer clip for early boss key (Glitched Logic)

# Mutoh's Temple
- 1F Skip one side with hammer (All Settings)
- B1 [Arrow despawn](https://www.youtube.com/watch?v=XvgpXRtiq0w) for puzzle and small key skips (Glitched Logic)
- B1 [Hammer pad skew](https://www.youtube.com/watch?v=qZzMGVTJMHE) and Spirit of Power level 1 can skip bow. Works with both bombs and chus (Glitched Logic)

==> worlds_tloz_ph-0.7.6.tar.gz: worlds_tloz_ph-0.7.6/src/worlds/tloz_ph/docs/tricks_and_skips.md <==
# List of tricks, skips and glitches by area, marked with logic requirements and with video links when available
Thanks to the [glitches spreadsheet](https://docs.google.com/spreadsheets/d/18NCGJjt9wil1gnRB2rZO9DIv_5etKmRf0sAH66i5SVQ/edit?usp=sharing) for collecting everything relevant to the vanilla game!

## Mercay island
- [Swordless/bombless Mountain Passage](https://www.youtube.com/watch?v=6_J14xLnVWM). Savewarping from the back entrance of Mountain Passage also works (Glitched Logic)
- [Mercay out of bounds](https://www.youtube.com/watch?v=IcyfYE68LUQ). (Glitched Logic)

## TotOK
### Time Logic
Phantom hourglass time logic is now available! On easy, it calculates the time it takes to walk (no rolling) from one 
floor to the next with various items. It then calculates the time to get each location from the start of their floor, 
for various items. It does not account for golden time pots. Medium halves the logically required time, and hard 
quarters it, while beginner doubles it. The longest probable required amount of time is around 10 minutes for beginner, 
5 for easy, 2.5 for medium and 1.25 for hard. It will generate slightly more sand than necessary based on your settings.
There's also a setting for how to count hearts as time, for only requiring the phantom hourglass item or for not 
calculating logic at all! Good luck!

### Tricks and Skips
- Kill b1 phantoms with
  - Phantom Sword (all settings)
  - Bow or (Sword + 2 Spirits of Power) or Hammer (Kill phantoms with stun). Push them into the pit by the grapple pegs
  - Grappling Hook (Kill phantoms with weapon)
 - B2 hit swtiches with pots from floor above (Hard Logic)
 - B2 hit switch over fire with pot (Hard Logic)
 - B2 Have phantom pick up key
   - Throw pot at phantom to pick it up (Normal logic)
   - Lure phantom to start of room (Hard Logic)
 - B2 [boomerang return key](https://www.youtube.com/watch?v=ftt3lP_qQDc) (doesn't effect logic)
 - B2 hammer clip bombchu switch (Glitched logic)
 - B3 Kill all phantoms (kill phantoms with traps)
 - B4 throw pot from floor above to hit switch behind SE gust of wind (Hard logic)
 - B4 [Boomerang return key](https://youtu.be/FbvG2Jzs68g?t=14) (Glitched logic)
 - B4 hit switches with hammer clips (Glitched Logic)
 - B5 [Chest backwards with BCL and boomerang](https://youtu.be/5597wXT0E1E) (Doesn't effect logic, but saves a key!)
 - B7 push phantoms into pits (kill phantoms with stun/weapon)
 - B8 push phantoms into pits (kill phantoms with stun/weapon)
 - B8 Hammer clip bombchu switch (Glitched Logic)
 - B10 Hammer switches (doesn't effect logic)

## Cannon island
 - [Bomb garden skip](https://www.youtube.com/watch?v=KtJ2GkNlr3E) (doesn't effect logic)

## Isle of Ember
- [Grapple chest without grapple](https://www.youtube.com/watch?v=IZiyFStyRfg) (Glitched Logic)

## Temple of Fire
- Hit 1F spin switch with things other than sword: bombs, chus and boomerang (Hard Logic)
- [Rat key early](https://www.youtube.com/watch?v=OJ-CwmYvWrc) (really tricky to kill rat with just boomerang, doesn't effect logic if killed with hammer clip)

## Temple of Courage
- 1F Hammer clip all the switches (Glitched Logic)
- B1 Invisible maze early
  - With grapple (all settings)
  - [With boomerang](https://www.youtube.com/watch?v=2DAUMNNQNhw) (Glitched Logic)
- B1 Boomerang Skip with Spirit of Courage (Not Implemented)

## Nyave's Ship
- Kill miblins with barrels (Hard Logic)

## Temple of Wind
- [Boss key early](https://www.youtube.com/watch?v=16hl9_mOLds) (not implemented)
- [B1 out of bounds](https://www.youtube.com/watch?v=ertGqXyGL-c) (doesn't effect logic)

## Ghost Ship
- B3 hammer clip switch (doesn't effect logic)

## Goron Island
- [Goron Temple early](https://www.youtube.com/watch?v=tUjm0CZAEVU) (Hard Logic)

## Goron Temple
- Hammer clips (Glitched logic)
- B2 early shortcut [rock roll](https://www.youtube.com/watch?v=FrdBA7idCWI) [BCL](https://www.youtube.com/watch?v=BUWBODrGF-0) (Doesn't effect logic)
- [Boss key early](https://www.youtube.com/watch?v=BUWBODrGF-0) (Doesn't effect logic)
- [Boss key skip](https://www.youtube.com/watch?v=Z4cupNcYcUg) (Not Implemented)

## Dee Ess Island
- Kill Eye brutes with their own bombs (Hard Logic)

## Temple of Ice
- 1F [Color Switch early](https://www.youtube.com/watch?v=na6olZJgE3M) (Hard Logic)
- 3F Hit entrance switch with bomb held over head (All Settings)
- 3F hit boomerang switches with bow (Hard Logic)
- 1F shortcut hammer clip (Glitched Logic)
- B1 Hammer clip color switch (Glitched logic)
- B1 [BCL switch skip](https://www.youtube.com/watch?v=aED-Yp_5MXo) (Glitched Logic)
- B1 Jump to boomerang switches and hit with bow (Hard Logic)
- B2 Hammer clip for early boss key (Glitched Logic)

# Mutoh's Temple
- 1F Skip one side with hammer (All Settings)
- B1 [Arrow despawn](https://www.youtube.com/watch?v=XvgpXRtiq0w) for puzzle and small key skips (Glitched Logic)
- B1 [Hammer pad skew](https://www.youtube.com/watch?v=qZzMGVTJMHE) and Spirit of Power level 1 can skip bow. Works with both bombs and chus (Glitched Logic)
